@@ -4,6 +4,7 @@ import time as _time
 import os as _os
 import base64 as _base64
 import string as _string
+import shutil as _shutil
 from . import color as _color
 
 if _os.name == "posix":
@@ -14,35 +15,6 @@ def _merge_string_list(obj: list):
     for text in obj: new_string += text
     return new_string
 
-class StringBytes:
-    @staticmethod
-    def encode(content: str, save: bool = False, save_path:str=None):
-        if not save and save_path is not None:
-            raise ValueError("save is off, but still have save path")
-        elif save and save_path is None:
-            raise ValueError("save is on, but save path is None")
-        elif save and save_path is not None:
-            file = open(save_path, "wb")
-            file.write(_base64.b64encode(content.encode("ascii")))
-            file.close()
-        else:
-            return _base64.b64encode(content.encode("ascii"))
-    @staticmethod
-    def decode(_bytes: bytes = None, read: bool = False, read_path: str = None):
-        if _bytes is not None and read:
-            raise ValueError("Bytes have been passed in but read mode is still on")
-        elif not read and read_path is not None:
-            raise ValueError("read is off, but still have read path")
-        elif read and read_path is None:
-            raise ValueError("read is on, but read path is None")
-        elif read and read_path is not None:
-            file = open(read_path, "rb")
-            content = _base64.b64decode(file.read()).decode("utf-8")
-            file.close()
-            return content
-        else:
-            return _base64.b64decode(_bytes).decode("utf-8")
-
 def decimal(obj: float):
     _obj = str(obj)
     returned = []
@@ -53,6 +25,7 @@ def decimal(obj: float):
     rstring = ""
     for char in returned: rstring += char
     return rstring
+    
 def Round(obj: float, _to: int = 0):
     if not _to: return round(obj)
     if len(str(decimal(obj))) < _to:
@@ -83,6 +56,7 @@ def Round(obj: float, _to: int = 0):
     res = Object + "." + decimals
     if AddOne: return float(res) + 1
     else: return float(res)
+    
 def Range(range_x: int or float, range_y: int or float = None, step: int or float = None):
     if range_y is None: range_y = range_x; range_x = 0
     if step is None: step = 1
@@ -94,107 +68,46 @@ def Range(range_x: int or float, range_y: int or float = None, step: int or floa
         while range_x >= range_y:
             yield range_x
             range_x -= step
+            
 def frange(a: list, start=0, end=0): return range(start, len(a) + end)
-def calculator(algorithm: str) -> int or float:
-    class cache(): 
-        def __init__(self, value: object) -> None: self.value = value
-        def clear(self) -> None: self.value = ""; self = None
-    def Indexs(mainlist:list, listarg: list) -> list:
-        p = [].copy()
-        for index in range(len(mainlist)):
-            if mainlist[index] == listarg:
-                p.append(index)
-        return p
-    algm: list = list(algorithm)
-    Sposes: list = None
-    Dposes: list = None
-    Qposes: list = None
-    if "*" in algm: Sposes: list = Indexs(algm, "*")
-    if "/" in algm: Dposes: list = Indexs(algm, "/")
-    if "^" in algm: Qposes: list = Indexs(algm, "^")
-    caches: cache = cache(str())
-    for index in range(len(algm)):
-        if algm[index] != " ": caches.value += algm[index]
-    # 这里去处空格
-    algm = list(caches.value); caches.clear()
-    count: int = int()
-    # 数字合并
-    while True:
-        try:
-            if algm[count] == ".":
-                p = str()
-                for x in algm[count - 1: count + 2]: p += str(x)
-                del algm[count - 1: count + 2]
-                algm.insert(count - 1, p)
-            if algm[count] == "-":
-                X = algm[count] + algm[count + 1]
-                del algm[count: count + 2]
-                algm.insert(count, X)
-            x: str = str(int(algm[count]))
-            y: str = str(int(algm[count + 1]))
-            del algm[count: count + 2]
-            algm.insert(count, x + y)
-            count = 0
-        except ValueError: count += 1; continue
-        except IndexError: break
-    # 转化数字
-    for index in range(len(algm)):
-        try: algm[index] = float(algm[index])
-        except ValueError: continue
-    # 加减运算
-    if not Sposes and not Dposes and not Qposes:
-        while True or True or True or True:
-            try:
-                p = algm[0] + algm[2]
-                del algm[:3]
-                algm.insert(0, p)
-            except IndexError: break
-            
-        return algm[0]
-    else:
-        caches: cache = cache(int())
-        counts: cache = cache(list())
-        #while "(" in algm:
-            
-        if "*" in algm: Sposes: list = Indexs(algm, "*")
-        if "/" in algm: Dposes: list = Indexs(algm, "/")
-        if "^" in algm: Qposes: list = Indexs(algm, "^")
-        sort = dict().copy()
-        for positions in Sposes: sort[positions] = "Sposes"
-        for positions in Dposes: sort[positions] = "Dposes"
-        for positions in Qposes: sort[positions] = "Qposes"
-        # insert SDQ to sort dict
-        position = dict()
-        poslist = sorted(sort.keys())
-        for pos in poslist: position[pos] = sort[pos]
-        count = 0
-        for index, types in position.items():
-            index -= count
-            if types == "Sposes": X = algm[index - 1] * algm[index + 1]
-            if types == "Dposes": X = algm[index - 1] / algm[index + 1]
-            if types == "Qposes": X = algm[index - 1] ** algm[index + 1]
-            del algm[index - 1: index + 2]
-            count += 2
-            algm.insert(index - 1, X)
-        new_algorithm = str()
-        for algms in algm: new_algorithm += str(algms)
-        return calculator(new_algorithm)
-
-
-def get_ttyinfo():
-    fd = _system.stdin.fileno()
-    old_ttyinfo = _termios.tcgetattr(fd)
-    new_ttyinfo = old_ttyinfo[:]
-    new_ttyinfo[3] &= ~_termios.ICANON
-    new_ttyinfo[3] &= ~_termios.ECHO
-    return fd, old_ttyinfo, new_ttyinfo
-
-
-# Convert variable name to string
-def nameof(var):
-    callers_local_vars = _inspect.currentframe().f_back.f_locals.items()
-    return [var_name for var_name, var_val in callers_local_vars if var_val is var][0]
 
+def center(string):
+    cols, rows = _shutil.get_terminal_size()
+    space = cols / 2
+    space = int(space - len(string) / 2)
+    print("{}{}".format(int(space) * " ", string))
+    
+class UI:
+    def __init__(self, mode=print):
+        self.console_length = _os.get_terminal_size()[0]
+        self.options = {}
+        self.write = mode
+        self.layer = ["title", "desc", "options"]
+    
+    def reset_console_length(self):
+        self.console_length = _os.get_terminal_size()[0]
+    
+    def setTitle(self, title):
+        self.title = title
+        self.title_length = len(title)
+        
+    def setOptions(self, options):
+        self.options[options] = len(options)
+    
+    def setLayer(self, layer: list):
+        self.layer = layer
+    
+    def plot(self):
+        print(self.console_length)
+        options = list(self.options.keys())
+        length = list(self.options.values())
+        title_pos = self.console_length // 2
+        #title_pos -= self.title_length
+        #print(title)
+        title = " " * title_pos + self.title
+        self.write(title)
+        
+ 
 def breakdown(obj):
     return_list = [].copy()
     for index in range(len(obj)):
@@ -291,92 +204,40 @@ class console:
                     if wd == w[0]: _time.sleep(w[1])
             _system.stdout.flush()
         print(end=end, flush=True)
-    @staticmethod
-    def read(putout: str = "", rtype=str, **args):
-        console.write(putout, end="", **args)
-        return rtype(input(""))
+
     @staticmethod
     def clearline(): _system.stdout.write("\r" + " " * _os.get_terminal_size().columns + "\r"); _system.stdout.flush()
     @staticmethod
     def reline(): print(end="\033[F", flush=True)
-    if _os.name == "posix":
-        import termios as _termios
-        @staticmethod
-        def simulation(desc="command: ", key_event=lambda **kwargs: tuple(kwargs.values())):
-            import subprocess
-            subprocess.run("", shell=True)
-            cs = cursor()
-            def writef(content):
-                _system.stdout.write(content)
-                _system.stdout.flush()
-            command = ""
-            ttyinfo = get_ttyinfo()
-            key = ""
-            writef(desc)
-            while 1:
-                _termios.tcsetattr(ttyinfo[0], _termios.TCSANOW, ttyinfo[2])
-                key = _os.read(ttyinfo[0], 7).decode("utf-8")
-                _termios.tcsetattr(ttyinfo[0], _termios.TCSANOW, ttyinfo[1])
-                if key == "\n": break
-                elif key == "\x7f":
-                    try:
-                        ocmd = list(command)
-                        del ocmd[cs.position().x - 2]
-                        command = _merge_string_list(ocmd)
-                        writef("\r" + " " * (len(command) + len(desc) + 1) + "\r")
-                        writef(desc + command)
-                        continue
-                    except IndexError:
-                        command = ""
-                        writef("\r" + " " * (len(command) + len(desc) + 1) + "\r")
-                        writef(desc + command)
-                        continue
-                elif key == "\x1b[A" or key == "\x1b[B": key = ""
-                
-                command, key, ttyinfo = key_event(command = command, key = key, ttyinfo = ttyinfo)
-                #print(cs.position().x)
-                if len(command) >= cs.position().x:
-                    lcmd = list(command)
-                    lcmd.insert(cs.position().x - 1, key)
-                    command = _merge_string_list(lcmd)
-                else: command += key
-                writef("\r" + desc + command)
-            print(flush = True)
-            command = command.split(" ")
-            return command
 
-class Bytes:
-    def __init__(self, obj, tag="b"):
-        if type(obj) is list: self.object = obj
-        else: self.object = [obj]
-        self.length = len(obj)
-        self.tag = tag.upper()
-        self.tags = ["BIT", "B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB", "BB", "NB", "DB",
-                    "bit", "b", "KiB", "MiB", "GiB", "TiB", "PiB", "EiB", "ZiB", "BiB", "NiB", "DiB"]
-        self.__check__(tag)
-        
-    def __check__(self, obj):
-        if obj in self.tags: pass
-        elif obj.upper() in self.tags: pass
-        else: raise TypeError(f"unknown byte type \"{obj}\"")
+def compare(dict1, dict2):
+    for key in dict1:
+        if key not in dict2: return key # Missing key
+    for key, value in dict2.items():
+        if type(value) is dict:
+            Missing_key = compare(dict1[key], value)
+            if Missing_key: return Missing_key
+    return ""  
+
+class Array:
+    def __init__(self, length=0, obj=[]):
+        self.obj = obj[:length] if type(obj) is not list else list(obj)
+        self.length = length
     
-    def convert(self, ByteType: str):
-        self.__check__(ByteType)
-        if self.tag.lower() == "bit" or ByteType.lower() == "bit":
-            pass
+    def __str__(self):
+        return list(self.obj[:self.length]).__str__()
+    
+    def __getitem__(self, index):
+        if type(index) is int:
+            if index >= self.length:
+                raise IndexError(f"index big then or equal length, index should be <= {self.length - 1}")
+            return self.obj[index]
         else:
-            index = self.tags.index(self.tag)
-            convertindex = self.tags.index(ByteType)
-            out = self.tags[index: convertindex]
-            for _ in frange(out):
-                if index > convertindex: self.length = self.length * 1024
-                else: self.length = self.length / 1024
-            self.tag = ByteType
-            
-            newObj = list()
-            
+            return self.obj[self.obj[:self.length][:self.length].index(index)]
             
 
+
+    
 if _os.name == "posix":
     import re as _re
     import tty as _tty
@@ -405,7 +266,7 @@ if _os.name == "posix":
             self.kwargs = kwargs
             self.sftp = self.__SFTP(None)
     
-        def connect(self, timeout: int = 3, wait_time: float = 5.5):
+        def connect_server(self, timeout: int = 3, wait_time: float = 5.5):
             while True:
                 try:
                     self.ssh.connect(self.host, self.port, self.user, self.password, key_filename=self.keypath, **self.kwargs)
@@ -416,6 +277,12 @@ if _os.name == "posix":
                     if timeout <= 0:
                         return error
             self.sftp = self.__SFTP(self.ssh)
+        def connect(self):
+            try:
+                self.ssh.connect(self.host, self.port, self.user, self.password, key_filename=self.keypath, **self.kwargs)
+                return True
+            except Exception:
+                return False
     
         def get_connect_count(self):
             return int(self.send("netstat -na | grep ESTABLISHED | wc -l").get("stdout"))
