@@ -1,3 +1,4 @@
+import re
 __color__ = \
 [
         "\033[0m",
@@ -105,16 +106,37 @@ cyan = __cyan__()
 white = __white__()
 
 class toning:
-    def font(R: int = 255, G: int = 255, B: int = 255, text: str = None):
+    def font(R = 255, G: int = 255, B: int = 255, text: str = None):
+        if type(R) is str:
+            RGB = []
+            for i in (0, 2, 4):
+                RGB.append(int(R[i: i+2], 16))
+            R, G, B = RGB
+            
         if text is not None: return f"\033[38;2;{R};{G};{B}m{text}\033[0m"
         return f"\033[38;2;{R};{G};{B}m"
     def background(R: int = 255, G: int = 255, B: int = 255, text: str = None):
+        if type(R) is str:
+            RGB = []
+            for i in (0, 2, 4):
+                RGB.append(int(R[i: i+2], 16))
+            R, G, B = RGB
         if text is not None: return f"\033[48;2;{R};{G};{B}m{text}\033[0m"
         return f"\033[48;2;{R};{G};{B}m"
 
+def remove_7bit(text):
+    return re.compile(r'\x1B(?:[@-Z\\-_]|\[[0-?]*[ -/]*[@-~])').sub("", text)
 
+def remove(text):
+    # remove 8 bit content
+    return re.compile(r'(?:\x1B[@-Z\\-_]|[\x80-\x9A\x9C-\x9F]|(?:\x1B\[|\x9B)[0-?]*[ -/]*[@-~])').sub("", text)
 
+def hex_convert(rh: str or list or tuple, obj: str = "ft"):
+    rh = rh.strip("#") if type(rh) is str else rh
+    return "#%02x%02x%02x" % tuple(rh) if type(rh) in (list, tuple) else tuple(int(rh[i: i+2], 16) for i in (0, 2, 4))
 
-
-
+def color(C: str or list or tuple, obj: str = "font"):
+    C = hex_convert(C) if type(C) is str else tuple(C)
+    return toning.font(*C) if "f" in obj else toning.background(*C)
+    
 
